@@ -17,10 +17,14 @@
 
 set -e
 
-sudo apt-get update && sudo apt-get install python3 -y
+if [ "$(uname)" = "Linux" ]; then
+  # github action runs on ubuntu, we might need to install python3 and pip3
+  sudo apt-get update && sudo apt-get install python3 -y
+  sudo apt install python3-pip
+fi
+
 # creating python virtual env
 python3 -m venv ~/.python3venv
 source ~/.python3venv/bin/activate
-sudo apt install python3-pip
 pip3 install wheel  # install wheel first explicitly
 pip3 install --upgrade pyyaml
