@@ -166,7 +166,7 @@ public class FilterPartitionBenchmark
     indexFile = INDEX_MERGER_V9.persist(
         incIndex,
         tmpDir,
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     qIndex = INDEX_IO.loadIndex(indexFile);
