@@ -310,7 +310,7 @@ public class GroupByTypeInterfaceBenchmark
       final File file = INDEX_MERGER_V9.persist(
           index,
           new File(tmpDir, String.valueOf(i)),
-          IndexSpec.DEFAULT,
+          IndexSpec.getDefault(),
           null
       );
 
