@@ -185,7 +185,7 @@ public class IndexPersistBenchmark
     File indexFile = INDEX_MERGER_V9.persist(
         incIndex,
         tmpDir,
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
 
