@@ -34,7 +34,8 @@ import org.apache.iceberg.expressions.Expression;
     @JsonSubTypes.Type(name = "and", value = IcebergAndFilter.class),
     @JsonSubTypes.Type(name = "not", value = IcebergNotFilter.class),
     @JsonSubTypes.Type(name = "or", value = IcebergOrFilter.class),
-    @JsonSubTypes.Type(name = "range", value = IcebergRangeFilter.class)
+    @JsonSubTypes.Type(name = "range", value = IcebergRangeFilter.class),
+    @JsonSubTypes.Type(name = "timeWindow", value = IcebergTimeWindowFilter.class)
 })
 public interface IcebergFilter
 {
