@@ -29,11 +29,12 @@ import org.apache.commons.codec.digest.DigestUtils;
 import org.apache.druid.data.input.impl.DimensionSchema;
 import org.apache.druid.data.input.impl.DimensionsSpec;
 import org.apache.druid.indexer.HadoopIOConfig;
+import org.apache.druid.indexer.HadoopIndexTask;
 import org.apache.druid.indexer.HadoopIngestionSpec;
+import org.apache.druid.indexer.HadoopTaskConfig;
 import org.apache.druid.indexer.HadoopTuningConfig;
 import org.apache.druid.indexer.granularity.ArbitraryGranularitySpec;
 import org.apache.druid.indexer.hadoop.DatasourceIngestionSpec;
-import org.apache.druid.indexing.common.task.HadoopIndexTask;
 import org.apache.druid.indexing.overlord.IndexerMetadataStorageCoordinator;
 import org.apache.druid.indexing.overlord.TaskMaster;
 import org.apache.druid.indexing.overlord.TaskStorage;
@@ -44,7 +45,6 @@ import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.granularity.Granularities;
 import org.apache.druid.metadata.MetadataSupervisorManager;
-import org.apache.druid.metadata.SqlSegmentsMetadataManager;
 import org.apache.druid.query.aggregation.AggregatorFactory;
 import org.apache.druid.segment.indexing.DataSchema;
 import org.apache.druid.segment.realtime.ChatHandlerProvider;
@@ -76,7 +76,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
   private final ObjectMapper objectMapper;
   private final MetadataSupervisorManager metadataSupervisorManager;
   private final IndexerMetadataStorageCoordinator metadataStorageCoordinator;
-  private final SqlSegmentsMetadataManager sqlSegmentsMetadataManager;
   private final TaskMaster taskMaster;
   private final TaskStorage taskStorage;
   private final MaterializedViewTaskConfig config;
@@ -100,7 +99,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
       @JacksonInject TaskMaster taskMaster,
       @JacksonInject TaskStorage taskStorage,
       @JacksonInject MetadataSupervisorManager metadataSupervisorManager,
-      @JacksonInject SqlSegmentsMetadataManager sqlSegmentsMetadataManager,
       @JacksonInject IndexerMetadataStorageCoordinator metadataStorageCoordinator,
       @JacksonInject MaterializedViewTaskConfig config,
       @JacksonInject AuthorizerMapper authorizerMapper,
@@ -142,7 +140,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
     this.taskMaster = taskMaster;
     this.taskStorage = taskStorage;
     this.metadataSupervisorManager = metadataSupervisorManager;
-    this.sqlSegmentsMetadataManager = sqlSegmentsMetadataManager;
     this.metadataStorageCoordinator = metadataStorageCoordinator;
     this.authorizerMapper = authorizerMapper;
     this.chatHandlerProvider = chatHandlerProvider;
@@ -183,7 +180,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
         tuningConfig.getAppendableIndexSpec(),
         tuningConfig.getMaxRowsInMemory(),
         tuningConfig.getMaxBytesInMemory(),
-        tuningConfig.isUseMaxMemoryEstimates(),
         tuningConfig.isLeaveIntermediate(),
         tuningConfig.isCleanupOnFailure(),
         tuningConfig.isOverwriteFiles(),
@@ -250,7 +246,8 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
         objectMapper,
         context,
         authorizerMapper,
-        chatHandlerProvider
+        chatHandlerProvider,
+        new HadoopTaskConfig(null, null)
     );
 
     return task;
@@ -354,7 +351,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
         taskMaster,
         taskStorage,
         metadataSupervisorManager,
-        sqlSegmentsMetadataManager,
         metadataStorageCoordinator,
         config,
         this
@@ -385,7 +381,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
         taskMaster,
         taskStorage,
         metadataSupervisorManager,
-        sqlSegmentsMetadataManager,
         metadataStorageCoordinator,
         config,
         authorizerMapper,
@@ -412,7 +407,6 @@ public class MaterializedViewSupervisorSpec implements SupervisorSpec
         taskMaster,
         taskStorage,
         metadataSupervisorManager,
-        sqlSegmentsMetadataManager,
         metadataStorageCoordinator,
         config,
         authorizerMapper,
