@@ -29,7 +29,8 @@ import org.apache.druid.query.aggregation.AggregatorUtil;
 import org.apache.druid.query.aggregation.PostAggregator;
 import org.apache.druid.query.aggregation.datasketches.quantiles.DoublesSketchAggregatorFactory;
 import org.apache.druid.query.cache.CacheKeyBuilder;
-import org.apache.druid.segment.column.ValueType;
+import org.apache.druid.segment.ColumnInspector;
+import org.apache.druid.segment.column.ColumnType;
 
 import javax.annotation.Nullable;
 import java.util.Comparator;
@@ -94,11 +95,12 @@ public class ArrayOfDoublesSketchToQuantilesSketchPostAggregator extends ArrayOf
 
   /**
    * actual type is {@link DoublesSketch}
+   * @param signature
    */
   @Override
-  public ValueType getType()
+  public ColumnType getType(ColumnInspector signature)
   {
-    return ValueType.COMPLEX;
+    return ArrayOfDoublesSketchModule.MERGE_TYPE;
   }
 
   @JsonProperty
