@@ -25,7 +25,6 @@ import com.google.inject.Inject;
 import com.google.inject.Injector;
 import org.apache.druid.client.coordinator.Coordinator;
 import org.apache.druid.concurrent.LifecycleLock;
-import org.apache.druid.discovery.DruidLeaderClient;
 import org.apache.druid.guice.ManageLifecycle;
 import org.apache.druid.guice.annotations.Smile;
 import org.apache.druid.java.util.common.FileUtils;
@@ -37,9 +36,10 @@ import org.apache.druid.java.util.common.concurrent.ScheduledExecutors;
 import org.apache.druid.java.util.common.lifecycle.LifecycleStart;
 import org.apache.druid.java.util.common.lifecycle.LifecycleStop;
 import org.apache.druid.java.util.emitter.EmittingLogger;
-import org.apache.druid.java.util.http.client.Request;
 import org.apache.druid.java.util.http.client.response.BytesFullResponseHandler;
 import org.apache.druid.java.util.http.client.response.BytesFullResponseHolder;
+import org.apache.druid.rpc.RequestBuilder;
+import org.apache.druid.rpc.ServiceClient;
 import org.apache.druid.security.basic.BasicAuthCommonCacheConfig;
 import org.apache.druid.security.basic.BasicAuthUtils;
 import org.apache.druid.security.basic.authorization.BasicRoleBasedAuthorizer;
@@ -79,7 +79,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
   private final Injector injector;
   private final ObjectMapper objectMapper;
   private final LifecycleLock lifecycleLock = new LifecycleLock();
-  private final DruidLeaderClient druidLeaderClient;
+  private final ServiceClient coordinatorClient;
   private final BasicAuthCommonCacheConfig commonCacheConfig;
   private final ScheduledExecutorService exec;
 
@@ -88,7 +88,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
       Injector injector,
       BasicAuthCommonCacheConfig commonCacheConfig,
       @Smile ObjectMapper objectMapper,
-      @Coordinator DruidLeaderClient druidLeaderClient
+      @Coordinator ServiceClient coordinatorClient
   )
   {
     this.exec = Execs.scheduledSingleThreaded("CoordinatorPollingBasicAuthorizerCacheManager-Exec--%d");
@@ -100,7 +100,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
     this.cachedGroupMappingMaps = new ConcurrentHashMap<>();
     this.cachedGroupMappingRoleMaps = new ConcurrentHashMap<>();
     this.authorizerPrefixes = new HashSet<>();
-    this.druidLeaderClient = druidLeaderClient;
+    this.coordinatorClient = coordinatorClient;
   }
 
   @LifecycleStart
@@ -135,6 +135,9 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
               }
               LOG.debug("Scheduled userMap cache poll is done");
             }
+            catch (InterruptedException e) {
+              LOG.noStackTrace().info(e, "Interrupted while polling Coordinator for cachedUserMaps.");
+            }
             catch (Throwable t) {
               LOG.makeAlert(t, "Error occurred while polling for cachedUserMaps.").emit();
             }
@@ -161,6 +164,9 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
               }
               LOG.debug("Scheduled groupMappingMap cache poll is done");
             }
+            catch (InterruptedException e) {
+              LOG.noStackTrace().info(e, "Interrupted while polling Coordinator for cachedGroupMappingMaps.");
+            }
             catch (Throwable t) {
               LOG.makeAlert(t, "Error occurred while polling for cachedGroupMappingMaps.").emit();
             }
@@ -183,7 +189,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
     }
 
     LOG.info("CoordinatorPollingBasicAuthorizerCacheManager is stopping.");
-    exec.shutdown();
+    exec.shutdownNow();
     LOG.info("CoordinatorPollingBasicAuthorizerCacheManager is stopped.");
   }
 
@@ -326,15 +332,17 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
   {
     try {
       return RetryUtils.retry(
-          () -> {
-            return tryFetchUserMapsFromCoordinator(prefix);
-          },
-          e -> true,
+          () -> tryFetchUserMapsFromCoordinator(prefix),
+          e -> !(e instanceof InterruptedException),
           commonCacheConfig.getMaxSyncRetries()
       );
     }
+    catch (InterruptedException e) {
+      LOG.noStackTrace().info(e, "Interrupted while fetching user and role map for authorizer[%s].", prefix);
+      return null;
+    }
     catch (Exception e) {
-      LOG.makeAlert(e, "Encountered exception while fetching user and role map for authorizer [%s]", prefix).emit();
+      LOG.makeAlert(e, "Encountered exception while fetching user and role map for authorizer[%s]", prefix).emit();
       if (isInit) {
         if (commonCacheConfig.getCacheDirectory() != null) {
           try {
@@ -343,7 +351,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
           }
           catch (Exception e2) {
             e2.addSuppressed(e);
-            LOG.makeAlert(e2, "Encountered exception while loading user-role map snapshot for authorizer [%s]", prefix)
+            LOG.makeAlert(e2, "Encountered exception while loading user-role map snapshot for authorizer[%s]", prefix)
                .emit();
           }
         }
@@ -357,15 +365,17 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
   {
     try {
       return RetryUtils.retry(
-          () -> {
-            return tryFetchGroupMappingMapsFromCoordinator(prefix);
-          },
-          e -> true,
+          () -> tryFetchGroupMappingMapsFromCoordinator(prefix),
+          e -> !(e instanceof InterruptedException),
           commonCacheConfig.getMaxSyncRetries()
       );
     }
+    catch (InterruptedException e) {
+      LOG.noStackTrace().info(e, "Interrupted while fetching group and role map for authorizer[%s].", prefix);
+      return null;
+    }
     catch (Exception e) {
-      LOG.makeAlert(e, "Encountered exception while fetching group and role map for authorizer [%s]", prefix).emit();
+      LOG.makeAlert(e, "Encountered exception while fetching group and role map for authorizer[%s]", prefix).emit();
       if (isInit) {
         if (commonCacheConfig.getCacheDirectory() != null) {
           try {
@@ -374,7 +384,7 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
           }
           catch (Exception e2) {
             e2.addSuppressed(e);
-            LOG.makeAlert(e2, "Encountered exception while loading group-role map snapshot for authorizer [%s]", prefix)
+            LOG.makeAlert(e2, "Encountered exception while loading group-role map snapshot for authorizer[%s]", prefix)
                .emit();
           }
         }
@@ -387,11 +397,11 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
       String prefix
   ) throws Exception
   {
-    Request req = druidLeaderClient.makeRequest(
+    RequestBuilder req = new RequestBuilder(
         HttpMethod.GET,
         StringUtils.format("/druid-ext/basic-security/authorization/db/%s/cachedSerializedUserMap", prefix)
     );
-    BytesFullResponseHolder responseHolder = druidLeaderClient.go(
+    BytesFullResponseHolder responseHolder = coordinatorClient.request(
         req,
         new BytesFullResponseHandler()
     );
@@ -411,11 +421,11 @@ public class CoordinatorPollingBasicAuthorizerCacheManager implements BasicAutho
       String prefix
   ) throws Exception
   {
-    Request req = druidLeaderClient.makeRequest(
+    RequestBuilder req = new RequestBuilder(
         HttpMethod.GET,
         StringUtils.format("/druid-ext/basic-security/authorization/db/%s/cachedSerializedGroupMappingMap", prefix)
     );
-    BytesFullResponseHolder responseHolder = druidLeaderClient.go(
+    BytesFullResponseHolder responseHolder = coordinatorClient.request(
         req,
         new BytesFullResponseHandler()
     );
