@@ -23,8 +23,8 @@ import com.fasterxml.jackson.annotation.JacksonInject;
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.annotation.JsonTypeName;
-import com.google.common.base.Joiner;
 import com.google.common.base.Preconditions;
+import org.apache.druid.error.DruidException;
 import org.apache.druid.guice.annotations.Self;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.logger.Logger;
@@ -41,8 +41,8 @@ import org.apache.hadoop.security.authentication.util.KerberosUtil;
 import org.apache.hadoop.security.authentication.util.Signer;
 import org.apache.hadoop.security.authentication.util.SignerException;
 import org.apache.hadoop.security.authentication.util.SignerSecretProvider;
-import org.eclipse.jetty.client.api.Request;
-import org.eclipse.jetty.http.HttpHeader;
+import org.eclipse.jetty.client.Request;
+import org.eclipse.jetty.http.HttpCookie;
 
 import javax.security.auth.Subject;
 import javax.security.auth.kerberos.KerberosPrincipal;
@@ -63,7 +63,6 @@ import javax.servlet.http.HttpServletRequestWrapper;
 import javax.servlet.http.HttpServletResponse;
 import java.io.File;
 import java.io.IOException;
-import java.net.HttpCookie;
 import java.security.Principal;
 import java.text.SimpleDateFormat;
 import java.util.Date;
@@ -75,8 +74,6 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 import java.util.TimeZone;
-import java.util.concurrent.ThreadLocalRandom;
-import java.util.stream.Collectors;
 
 
 @JsonTypeName("kerberos")
@@ -84,6 +81,7 @@ public class KerberosAuthenticator implements Authenticator
 {
   private static final Logger log = new Logger(KerberosAuthenticator.class);
   public static final String SIGNED_TOKEN_ATTRIBUTE = "signedToken";
+  private static final String COOKIE_SIGNATURE_SECRET_KEY = "cookieSignatureSecret";
 
   private final String serverPrincipal;
   private final String serverKeytab;
@@ -98,7 +96,7 @@ public class KerberosAuthenticator implements Authenticator
       @JsonProperty("serverPrincipal") String serverPrincipal,
       @JsonProperty("serverKeytab") String serverKeytab,
       @JsonProperty("authToLocal") String authToLocal,
-      @JsonProperty("cookieSignatureSecret") String cookieSignatureSecret,
+      @JsonProperty(COOKIE_SIGNATURE_SECRET_KEY) String cookieSignatureSecret,
       @JsonProperty("authorizerName") String authorizerName,
       @JsonProperty("name") String name,
       @JacksonInject @Self DruidNode node
@@ -106,6 +104,12 @@ public class KerberosAuthenticator implements Authenticator
   {
     this.serverKeytab = serverKeytab;
     this.authToLocal = authToLocal == null ? "DEFAULT" : authToLocal;
+    if (cookieSignatureSecret == null || cookieSignatureSecret.isEmpty()) {
+      throw DruidException.forPersona(DruidException.Persona.OPERATOR)
+                          .ofCategory(DruidException.Category.INVALID_INPUT)
+                          .build("[%s] is not set for Kerberos authenticator", COOKIE_SIGNATURE_SECRET_KEY);
+    }
+
     this.cookieSignatureSecret = cookieSignatureSecret;
     this.authorizerName = authorizerName;
     this.name = Preconditions.checkNotNull(name);
@@ -140,8 +144,10 @@ public class KerberosAuthenticator implements Authenticator
           Properties config = getConfiguration(configPrefix, filterConfig);
           String signatureSecret = config.getProperty(configPrefix + SIGNATURE_SECRET);
           if (signatureSecret == null) {
-            signatureSecret = Long.toString(ThreadLocalRandom.current().nextLong());
-            log.warn("'signature.secret' configuration not set, using a random value as secret");
+            throw DruidException.defensive(
+                "Config property[%s] is not set for Kerberos authenticator",
+                SIGNATURE_SECRET
+            );
           }
           final byte[] secretBytes = StringUtils.toUtf8(signatureSecret);
           SignerSecretProvider signerSecretProvider = new SignerSecretProvider()
@@ -381,9 +387,7 @@ public class KerberosAuthenticator implements Authenticator
     params.put("kerberos.keytab", serverKeytab);
     params.put(AuthenticationFilter.AUTH_TYPE, DruidKerberosAuthenticationHandler.class.getName());
     params.put("kerberos.name.rules", authToLocal);
-    if (cookieSignatureSecret != null) {
-      params.put("signature.secret", cookieSignatureSecret);
-    }
+    params.put(AuthenticationFilter.SIGNATURE_SECRET, cookieSignatureSecret);
     return params;
   }
 
@@ -422,11 +426,7 @@ public class KerberosAuthenticator implements Authenticator
     if (cookieToken != null && cookieToken instanceof String) {
       log.debug("Found cookie token will attache it to proxyRequest as cookie");
       String authResult = (String) cookieToken;
-      String existingCookies = proxyRequest.getCookies()
-                                           .stream()
-                                           .map(HttpCookie::toString)
-                                           .collect(Collectors.joining(";"));
-      proxyRequest.header(HttpHeader.COOKIE, Joiner.on(";").join(authResult, existingCookies));
+      proxyRequest.cookie(HttpCookie.from(SIGNED_TOKEN_ATTRIBUTE, authResult));
     }
   }
 
