@@ -21,11 +21,13 @@ package org.apache.druid.data.input.kafkainput;
 
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.google.common.base.Preconditions;
+import org.apache.druid.data.input.ColumnsFilter;
 import org.apache.druid.data.input.InputEntity;
 import org.apache.druid.data.input.InputEntityReader;
 import org.apache.druid.data.input.InputFormat;
 import org.apache.druid.data.input.InputRowSchema;
 import org.apache.druid.data.input.impl.ByteEntity;
+import org.apache.druid.data.input.impl.DimensionsSpec;
 import org.apache.druid.data.input.impl.JsonInputFormat;
 import org.apache.druid.data.input.impl.TimestampSpec;
 import org.apache.druid.data.input.kafka.KafkaRecordEntity;
@@ -33,7 +35,6 @@ import org.apache.druid.indexing.seekablestream.SettableByteEntity;
 import org.apache.druid.java.util.common.DateTimes;
 
 import javax.annotation.Nullable;
-
 import java.io.File;
 import java.util.Objects;
 
@@ -111,7 +112,12 @@ public class KafkaInputFormat implements InputFormat
                 (record.getRecord().key() == null) ?
                     null :
                     JsonInputFormat.withLineSplittable(keyFormat, false).createReader(
-                        newInputRowSchema,
+                        // for keys, discover all fields; in KafkaInputReader we will pick the first one.
+                        new InputRowSchema(
+                            dummyTimestampSpec,
+                            DimensionsSpec.builder().useSchemaDiscovery(true).build(),
+                            ColumnsFilter.all()
+                        ),
                         new ByteEntity(record.getRecord().key()),
                         temporaryDirectory
                     ),
