@@ -58,14 +58,13 @@ public class KafkaInputReader implements InputEntityReader
   private final String topicColumnName;
 
   /**
-   *
-   * @param inputRowSchema Actual schema from the ingestion spec
-   * @param source kafka record containing header, key & value that is wrapped inside SettableByteEntity
+   * @param inputRowSchema       Actual schema from the ingestion spec
+   * @param source               kafka record containing header, key & value that is wrapped inside SettableByteEntity
    * @param headerParserSupplier Function to get Header parser for parsing the header section, kafkaInputFormat allows users to skip header parsing section and hence an be null
-   * @param keyParserSupplier Function to get Key parser for key section, can be null as well. Key parser supplier can also return a null key parser.
-   * @param valueParser Value parser is a required section in kafkaInputFormat. It cannot be null.
-   * @param keyColumnName Default key column name
-   * @param timestampColumnName Default kafka record's timestamp column name
+   * @param keyParserSupplier    Function to get Key parser for key section, can be null as well. Key parser supplier can also return a null key parser.
+   * @param valueParser          Value parser is a required section in kafkaInputFormat. It cannot be null.
+   * @param keyColumnName        Default key column name
+   * @param timestampColumnName  Default kafka record's timestamp column name
    */
   public KafkaInputReader(
       InputRowSchema inputRowSchema,
@@ -144,14 +143,9 @@ public class KafkaInputReader implements InputEntityReader
       try (CloseableIterator<InputRow> keyIterator = keyParser.read()) {
         // Key currently only takes the first row and ignores the rest.
         if (keyIterator.hasNext()) {
-          // Return type for the key parser should be of type MapBasedInputRow
-          // Parsers returning other types are not compatible currently.
-          MapBasedInputRow keyRow = (MapBasedInputRow) keyIterator.next();
+          final InputRow keyRow = keyIterator.next();
           // Add the key to the mergeList only if the key string is not already present
-          mergedHeaderMap.putIfAbsent(
-              keyColumnName,
-              keyRow.getEvent().entrySet().stream().findFirst().get().getValue()
-          );
+          mergedHeaderMap.computeIfAbsent(keyColumnName, ignored -> getFirstValue(keyRow));
         }
       }
       catch (ClassCastException e) {
@@ -295,7 +289,7 @@ public class KafkaInputReader implements InputEntityReader
     final Set<String> keySet = new HashSet<>(fallback.keySet());
     keySet.addAll(rowDimensions);
 
-    return new AbstractMap<String, Object>()
+    return new AbstractMap<>()
     {
       @Override
       public Object get(Object key)
@@ -344,4 +338,15 @@ public class KafkaInputReader implements InputEntityReader
       }
     };
   }
+
+  /**
+   * Get the first value from an {@link InputRow}. This is the first element from {@link InputRow#getDimensions()}
+   * if there are any. If there are not any, returns null. This method is used to extract keys.
+   */
+  @Nullable
+  static Object getFirstValue(final InputRow row)
+  {
+    final List<String> dimensions = row.getDimensions();
+    return !dimensions.isEmpty() ? row.getRaw(dimensions.get(0)) : null;
+  }
 }
